@@ -1,5 +1,6 @@
 import base64
 import json
+import requests
 
 from pathlib import Path
 from requests.exceptions import HTTPError
@@ -48,6 +49,7 @@ def _create_model_deployment(*, model_client, model_version_id, docker_client):
         raise InvalidHandlerSyntax("invalid_model_handler")
 
     handler_data = base64.b64encode(handler_source.encode("utf-8")).decode()
+
     try:
         model_artifact = model_client.get_latest_model_artifact(
             model_version_id=model_version_id
@@ -123,7 +125,17 @@ def deploy_model(*, model_name, version):
         log.warn("ERROR: Unable to connect to docker, is it installed/running?")
         return
 
-    model_client = get_model_client(model_name=model_name, project_name=project_name)
+    try:
+        model_client = get_model_client(
+            model_name=model_name, project_name=project_name
+        )
+    except requests.exceptions.HTTPError as e:
+        if e.response.status_code == 400:
+            error_msg = e.response.json()["detail"]["non_field_errors"][0]
+            handle_error(error_msg=error_msg)
+            return None
+        else:
+            raise
 
     local_config_helper = LocalConfigHelper()
     local_model_config = local_config_helper.get_local_model_config(
