@@ -1,12 +1,13 @@
 import click
-from slai.modules.runtime import ValidRuntimes
 import yaml
 import os
 import slai
+import sys
 
 from pathlib import Path
 from slai_cli import log
 from slai_cli.exceptions import InvalidApiKey
+from slai.modules.runtime import ValidRuntimes
 
 
 def get_credentials(profile_name="default", runtime=ValidRuntimes.Project):
@@ -38,7 +39,11 @@ def store_credentials(*, profile_name, client_id, client_secret, runtime):
         "client_secret": client_secret,
     }
 
-    slai.login(client_id=client_id, client_secret=client_secret, key_type="USER")
+    try:
+        slai.login(client_id=client_id, client_secret=client_secret, key_type="USER")
+    except slai.exceptions.InvalidCredentials:
+        log.warn("Invalid credentials")
+        sys.exit(1)
 
     if runtime == ValidRuntimes.Local:
         credentials_path = f"{Path.home()}/.slai"
